import { DataSource, DataSourceOption, DataSourceVal, ValueProps } from '../../index';
import type { DB_ResourceFunction, RdData, RdDataArguments, RdDefineProp, RdDefinePropType } from '@elowcode/robotdev-design-types';
export interface BindDataProp {
    action: string;
    args: {
        [x: string]: any;
    };
}
export interface FormulaData {
    type?: string;
    mode: string;
    args: {
        [key: string]: RdDataArguments;
    };
}
export interface FormulaProps {
    title?: string;
    titleFormula?: string;
    value?: ValueProps;
    env?: 'front' | 'back' | undefined;
    isFormula?: (value: RdData) => boolean;
    keyLabelReplace?: {
        [key: string]: string;
    };
    showKeys?: DataSourceVal[];
    hideKeys?: DataSourceVal[];
    dataSourceOptions?: DataSourceOption[];
    dataSourceConfigs?: any[];
    getCurrentCmpt?: () => any;
    getActionArgs?: () => any[];
    getEventArgs?: () => any[];
    getPageOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getPageQuery?: (fn: (options: any[]) => void, args?: any) => void;
    getLabelByBindData?: (fn: (label: string) => void, bindData: any) => void;
    getLabelByComparator?: (mode: string) => string;
    getLabelByOperator?: (mode: string) => string;
    getBusinessOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getBusinessProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getForeachOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getForeachProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getSlotOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getSlotProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getCmptProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getVariableOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getBusinessParamOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getAnyData?: (config: [string, any], fn?: (data: any) => void) => Promise<any> | any;
    getSubOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getTypes?: (args?: any, option?: any) => any;
    validateTypes?: (targetTypes: RdDefinePropType[], currentTypes: RdDefinePropType[]) => any;
    formatSubmitValue?: (mode: string, value: RdData) => RdData;
    formatPropsValue?: (mode: string, value: RdData) => string[];
    getFormulaInfo?: (success: (data: {
        formulaName: string;
        parameters: RdDefineProp[];
        modeType: 'data' | 'function';
    }) => void, mode?: string) => void;
    getFormulaLabel?: (success: (data: {
        text?: string;
        title?: string;
    }) => void, rdData?: RdData) => void;
    setDisable?: (node: any) => boolean;
    getFormula?: (fn: (group: any, groupReturn: any) => void) => void;
    getInsertValue?: (success: (res: {
        status: boolean;
        value?: RdData;
        msg?: string;
    }) => void, targetTypes: RdDefinePropType[], selectType: 'fn' | 'data', selectNode: DB_ResourceFunction | any) => void;
    functionInfo?: {
        groups?: (success: (data: any) => void) => void;
        tree?: (success: (data: any) => void, gourpId: string, reload?: boolean) => void;
        views: (fn: (data: DB_ResourceFunction[]) => void, ids: string[]) => void;
        view?: (fn: (data: DB_ResourceFunction) => void, id: string, mode: string) => void;
    };
    actionInfo?: {
        groups?: (success: (data: any) => void) => void;
        tree?: (success: (data: any) => void, gourpId: string, reload?: boolean) => void;
        views: (fn: (data: DB_ResourceFunction[]) => void, ids: string[]) => void;
        view?: (fn: (data: DB_ResourceFunction) => void, id: string, mode: string) => void;
    };
}
declare const _default: import("vue").DefineComponent<{
    value: {
        type: import("vue").PropType<ValueProps>;
    };
    title: {
        type: import("vue").PropType<string>;
    };
    getOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getFormula: {
        type: import("vue").PropType<(fn: (group: any, groupReturn: any) => void) => void>;
    };
    getTypes: {
        type: import("vue").PropType<(args?: any, option?: any) => any>;
    };
    getSubOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    formatPropsValue: {
        type: import("vue").PropType<(mode: string, value: RdData) => string[]>;
    };
    formatSubmitValue: {
        type: import("vue").PropType<(mode: string, value: RdData) => RdData>;
    };
    actionInfo: {
        type: import("vue").PropType<{
            groups?: ((success: (data: any) => void) => void) | undefined;
            tree?: ((success: (data: any) => void, gourpId: string, reload?: boolean | undefined) => void) | undefined;
            views: (fn: (data: DB_ResourceFunction[]) => void, ids: string[]) => void;
            view?: ((fn: (data: DB_ResourceFunction) => void, id: string, mode: string) => void) | undefined;
        }>;
    };
    env: {
        type: import("vue").PropType<"front" | "back">;
        default: undefined;
    };
    isFormula: {
        type: import("vue").PropType<(value: RdData) => boolean>;
    };
    keyLabelReplace: {
        type: import("vue").PropType<{
            [key: string]: string;
        }>;
    };
    showKeys: {
        type: import("vue").PropType<("getApiData" | "getThirdPartyApiData" | "getVar" | "getEachData" | "getSlotData" | "getCmptPropData" | "getModelData" | "getParam" | "getFormula" | "custom" | "getAcArguments" | "getFcArguments" | "getEventData" | "getUserInfo")[]>;
    };
    hideKeys: {
        type: import("vue").PropType<("getApiData" | "getThirdPartyApiData" | "getVar" | "getEachData" | "getSlotData" | "getCmptPropData" | "getModelData" | "getParam" | "getFormula" | "custom" | "getAcArguments" | "getFcArguments" | "getEventData" | "getUserInfo")[]>;
    };
    getCurrentCmpt: {
        type: import("vue").PropType<() => any>;
    };
    getPageOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getPageQuery: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getLabelByBindData: {
        type: import("vue").PropType<(fn: (label: string) => void, bindData: any) => void>;
    };
    getLabelByComparator: {
        type: import("vue").PropType<(mode: string) => string>;
    };
    getLabelByOperator: {
        type: import("vue").PropType<(mode: string) => string>;
    };
    getBusinessOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getBusinessProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getForeachOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getForeachProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getSlotOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getSlotProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getCmptProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getVariableOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getBusinessParamOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getAnyData: {
        type: import("vue").PropType<(config: [string, any], fn?: ((data: any) => void) | undefined) => any>;
    };
    validateTypes: {
        type: import("vue").PropType<(targetTypes: RdDefinePropType[], currentTypes: RdDefinePropType[]) => any>;
    };
    getFormulaInfo: {
        type: import("vue").PropType<(success: (data: {
            formulaName: string;
            parameters: RdDefineProp<RdDefinePropType>[];
            modeType: "function" | "data";
        }) => void, mode?: string | undefined) => void>;
    };
    getFormulaLabel: {
        type: import("vue").PropType<(success: (data: {
            text?: string | undefined;
            title?: string | undefined;
        }) => void, rdData?: RdData | undefined) => void>;
    };
    setDisable: {
        type: import("vue").PropType<(node: any) => boolean>;
    };
    functionInfo: {
        type: import("vue").PropType<{
            groups?: ((success: (data: any) => void) => void) | undefined;
            tree?: ((success: (data: any) => void, gourpId: string, reload?: boolean | undefined) => void) | undefined;
            views: (fn: (data: DB_ResourceFunction[]) => void, ids: string[]) => void;
            view?: ((fn: (data: DB_ResourceFunction) => void, id: string, mode: string) => void) | undefined;
        }>;
    };
    getInsertValue: {
        type: import("vue").PropType<(success: (res: {
            status: boolean;
            value?: RdData | undefined;
            msg?: string | undefined;
        }) => void, targetTypes: RdDefinePropType[], selectType: "data" | "fn", selectNode: any) => void>;
    };
    getActionArgs: {
        type: import("vue").PropType<() => any[]>;
    };
    getEventArgs: {
        type: import("vue").PropType<() => any[]>;
    };
    dataSourceOptions: {
        type: import("vue").PropType<DataSourceOption[]>;
        default: () => ({
            value: DataSource;
            label: string;
            component?: undefined;
        } | {
            value: DataSource;
            label: string;
            component: {
                tag: string;
                props: {
                    title: string;
                };
            };
        } | {
            value: DataSource;
            label: string;
            component: {
                tag: string;
                props?: undefined;
            };
        })[];
    };
    dataSourceConfigs: {
        type: import("vue").PropType<any[]>;
    };
    titleFormula: {
        type: import("vue").PropType<string>;
    };
}, {}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {
    ok: (value: FormulaData) => void;
    cancel: () => void;
    select: (keys: string[], node: any) => void;
    expand: (keys: string[], node: any) => void;
    change: (value: any) => void;
    clear: () => void;
}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    value: {
        type: import("vue").PropType<ValueProps>;
    };
    title: {
        type: import("vue").PropType<string>;
    };
    getOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getFormula: {
        type: import("vue").PropType<(fn: (group: any, groupReturn: any) => void) => void>;
    };
    getTypes: {
        type: import("vue").PropType<(args?: any, option?: any) => any>;
    };
    getSubOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    formatPropsValue: {
        type: import("vue").PropType<(mode: string, value: RdData) => string[]>;
    };
    formatSubmitValue: {
        type: import("vue").PropType<(mode: string, value: RdData) => RdData>;
    };
    actionInfo: {
        type: import("vue").PropType<{
            groups?: ((success: (data: any) => void) => void) | undefined;
            tree?: ((success: (data: any) => void, gourpId: string, reload?: boolean | undefined) => void) | undefined;
            views: (fn: (data: DB_ResourceFunction[]) => void, ids: string[]) => void;
            view?: ((fn: (data: DB_ResourceFunction) => void, id: string, mode: string) => void) | undefined;
        }>;
    };
    env: {
        type: import("vue").PropType<"front" | "back">;
        default: undefined;
    };
    isFormula: {
        type: import("vue").PropType<(value: RdData) => boolean>;
    };
    keyLabelReplace: {
        type: import("vue").PropType<{
            [key: string]: string;
        }>;
    };
    showKeys: {
        type: import("vue").PropType<("getApiData" | "getThirdPartyApiData" | "getVar" | "getEachData" | "getSlotData" | "getCmptPropData" | "getModelData" | "getParam" | "getFormula" | "custom" | "getAcArguments" | "getFcArguments" | "getEventData" | "getUserInfo")[]>;
    };
    hideKeys: {
        type: import("vue").PropType<("getApiData" | "getThirdPartyApiData" | "getVar" | "getEachData" | "getSlotData" | "getCmptPropData" | "getModelData" | "getParam" | "getFormula" | "custom" | "getAcArguments" | "getFcArguments" | "getEventData" | "getUserInfo")[]>;
    };
    getCurrentCmpt: {
        type: import("vue").PropType<() => any>;
    };
    getPageOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getPageQuery: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getLabelByBindData: {
        type: import("vue").PropType<(fn: (label: string) => void, bindData: any) => void>;
    };
    getLabelByComparator: {
        type: import("vue").PropType<(mode: string) => string>;
    };
    getLabelByOperator: {
        type: import("vue").PropType<(mode: string) => string>;
    };
    getBusinessOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getBusinessProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getForeachOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getForeachProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getSlotOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getSlotProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getCmptProperties: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getVariableOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getBusinessParamOptions: {
        type: import("vue").PropType<(fn: (options: any[]) => void, args?: any) => void>;
    };
    getAnyData: {
        type: import("vue").PropType<(config: [string, any], fn?: ((data: any) => void) | undefined) => any>;
    };
    validateTypes: {
        type: import("vue").PropType<(targetTypes: RdDefinePropType[], currentTypes: RdDefinePropType[]) => any>;
    };
    getFormulaInfo: {
        type: import("vue").PropType<(success: (data: {
            formulaName: string;
            parameters: RdDefineProp<RdDefinePropType>[];
            modeType: "function" | "data";
        }) => void, mode?: string | undefined) => void>;
    };
    getFormulaLabel: {
        type: import("vue").PropType<(success: (data: {
            text?: string | undefined;
            title?: string | undefined;
        }) => void, rdData?: RdData | undefined) => void>;
    };
    setDisable: {
        type: import("vue").PropType<(node: any) => boolean>;
    };
    functionInfo: {
        type: import("vue").PropType<{
            groups?: ((success: (data: any) => void) => void) | undefined;
            tree?: ((success: (data: any) => void, gourpId: string, reload?: boolean | undefined) => void) | undefined;
            views: (fn: (data: DB_ResourceFunction[]) => void, ids: string[]) => void;
            view?: ((fn: (data: DB_ResourceFunction) => void, id: string, mode: string) => void) | undefined;
        }>;
    };
    getInsertValue: {
        type: import("vue").PropType<(success: (res: {
            status: boolean;
            value?: RdData | undefined;
            msg?: string | undefined;
        }) => void, targetTypes: RdDefinePropType[], selectType: "data" | "fn", selectNode: any) => void>;
    };
    getActionArgs: {
        type: import("vue").PropType<() => any[]>;
    };
    getEventArgs: {
        type: import("vue").PropType<() => any[]>;
    };
    dataSourceOptions: {
        type: import("vue").PropType<DataSourceOption[]>;
        default: () => ({
            value: DataSource;
            label: string;
            component?: undefined;
        } | {
            value: DataSource;
            label: string;
            component: {
                tag: string;
                props: {
                    title: string;
                };
            };
        } | {
            value: DataSource;
            label: string;
            component: {
                tag: string;
                props?: undefined;
            };
        })[];
    };
    dataSourceConfigs: {
        type: import("vue").PropType<any[]>;
    };
    titleFormula: {
        type: import("vue").PropType<string>;
    };
}>> & {
    onChange?: ((value: any) => any) | undefined;
    onSelect?: ((keys: string[], node: any) => any) | undefined;
    onOk?: ((value: FormulaData) => any) | undefined;
    onCancel?: (() => any) | undefined;
    onExpand?: ((keys: string[], node: any) => any) | undefined;
    onClear?: (() => any) | undefined;
}, {
    env: "front" | "back";
    dataSourceOptions: DataSourceOption[];
}>;
export default _default;
//# sourceMappingURL=Formula.vue.d.ts.map