import { DataSourceOption, DataSourceVal } from '../../../components/databind';
import type { RdData, DB_ResourceFunction, RdDefinePropType, RdDefineProp } from '@elowcode/robotdev-design-types';
export interface EventOpt {
    key: string;
    value: string;
    icon: string;
}
export interface ActionOpt {
    key: string;
    value: string;
}
export interface BindDataProp {
    action: string;
    args: {
        [x: string]: any;
    };
}
export interface DataBindPropsCommon {
    env?: 'front' | 'back' | undefined;
    types?: RdDefinePropType[];
    isFormula?: (value: RdData) => boolean;
    keyLabelReplace?: {
        [key: string]: string;
    };
    showKeys?: DataSourceVal[];
    hideKeys?: DataSourceVal[];
    dataSourceOptions?: DataSourceOption[];
    dataSourceConfigs?: any[];
    getCurrentCmpt?: () => any;
    getPageOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getPageQuery?: (fn: (options: any[]) => void, args?: any) => void;
    getLabelByBindData?: (fn: (label: string) => void, bindData: any) => void;
    getLabelByComparator?: (mode: string) => string;
    getLabelByOperator?: (mode: string) => string;
    getBusinessOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getBusinessProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getForeachOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getForeachProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getSlotOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getSlotProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getCmptProperties?: (fn: (options: any[]) => void, args?: any) => void;
    getVariableOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getBusinessParamOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getAnyData?: (config: [string, any], fn?: (data: any) => void) => Promise<any> | any;
    getSubOptions?: (fn: (options: any[]) => void, args?: any) => void;
    getTypes?: (args?: any, option?: any) => any;
    validateTypes?: (targetTypes: RdDefinePropType[], currentTypes: RdDefinePropType[]) => any;
    formatSubmitValue?: (mode: string, value: RdData) => RdData;
    formatPropsValue?: (mode: string, value: RdData) => string[];
    functionInfo?: {
        groups?: (success: (data: any) => void) => void;
        tree?: (success: (data: any) => void, gourpId: string, reload?: boolean) => void;
        views: (fn: (data: DB_ResourceFunction[]) => void, ids: string[]) => void;
        view?: (fn: (data: DB_ResourceFunction) => void, id: string, mode: string) => void;
    };
    getFormulaInfo?: (success: (data: {
        formulaName: string;
        parameters: RdDefineProp[];
        modeType: 'data' | 'function';
    }) => void, mode?: string) => void;
    getFormulaLabel?: (success: (data: {
        text?: string;
        title?: string;
    }) => void, rdData?: RdData) => void;
    setDisable?: (node: any) => boolean;
    getFormula?: (fn: (group: any, groupReturn: any) => void) => void;
    getInsertValue?: (success: (res: {
        status: boolean;
        value?: RdData;
        msg?: string;
    }) => void, targetTypes: RdDefinePropType[], selectType: 'fn' | 'data', selectNode: DB_ResourceFunction | any) => void;
    getActionArgs?: () => any[];
    getEventArgs?: () => any[];
    getFunctionArgs?: () => any[];
}
export interface InteractionPropsBase extends DataBindPropsCommon {
    eventTitle?: string;
    eventOptions?: any[];
    actionInfo?: {
        groups: (fn: (list: any[]) => void) => {};
        tree: (fn: (tree: any[]) => void, id: string, reload?: boolean) => {};
        views: (fn: (list: any[]) => void, ids: string[]) => {};
        view: (fn: (data: any) => void, mode: string) => {};
    };
    eventInfo?: Record<string, any>;
    operatorOptions?: any[];
    comparatorOptions?: any[];
    openWindowTypeOptions?: any[];
    openWindowTargetOptions?: any[];
}
export interface DataBindPropsBase extends DataBindPropsCommon {
}
//# sourceMappingURL=interaction.d.ts.map