declare type Recursion = (node: any, recursion: Function, layer: number, key: string | number, index: number, parent: any, data: any) => object;
declare const AS: {
    /**
     * 快速生成返回结果的数据结构
     * @param {string} status 状态，取值标准：0为验证通过，大于0为验证不通过需要显示文字信息,小于0视为验证通过，但仍需警告提示
     * @param {string} msg 文字信息
     * @param {string} data 要返回的数据
     * @return {object} {status,msg,data}
     */
    result: (status?: string | number, msg?: string | number, data?: any) => {
        status: string | number;
        msg: string | number;
        data: any;
    };
    /**
     * 字符串左右两边的空字符清空
     * @param {string} str 字符串
     * @return {string}
     */
    trim: (str?: string) => string;
    /**
     * 判断属性名或索引值是否存在于一个对象或数组中
     * @param {array|object} data 数据
     * @param {string} key 属性名(真实才视为true)或索引值
     * @param {object} some 是否使用some循环判断，使用some则一个符合就返回true，否则需要全部符合
     * @return {boolean}
     */
    hasProperty: (data: any, key: number | string | string[], some?: boolean) => any;
    /**
     * 判断2个值是否相等
     * @param {any} left 被判断的值
     * @param {any} right 对比的值
     * @param {function} before 判断前，先让左右值调用此函数返回新值再对比，目的是在判断前保持格式统一性
     * @return {boolean}
     */
    eq: (left: any, right: any, before?: any) => boolean;
    /**
     * 获取2个数组的交集
     * @param {any[]} left 数组1
     * @param {any[]} right 数组2
     * @return {boolean}
     */
    intersection: (left: any[], right: any[]) => any[];
    hasIntersection: (left: any[], right: any[]) => number;
    /**
     * 判断某一个或多个值是否存在指定的取值范围内
     * @param {any} left 被判断的值
     * @param {any} right 取值范围
     * @param {function} before 给eq函数的回调，请移到eq函数查看注释
     * @return {boolean}
     */
    includes: (left: any, right: any, before?: any) => any;
    includesArray: (left: any[], right: any[]) => boolean;
    /**
     * 判断值是否被排除或者需要
     * @param {any} value 被判断的值
     * @param {any[]} only 需要的值取值范围
     * @param {any[]} except 排除的值取值范围，优先级大于only
     * @param {function} before 给includes函数的回调，请移到includes函数查看注释
     * @return {boolean} 如果only和except都没有被指定则固定返回true
     */
    exceptOnly: (value: any, only: any, except: any, before?: any) => any;
    /**
     * js的substr方法复现，额外增加快速对比功能
     * @param {string} str 字符串
     * @param {number} start 开始位置
     * @param {number} end 结束位置
     * @param {string} right 要对比的字符
     * @return {string|boolean} 如果不指定right字符，则返回指定位置的字符串，否则将返回对比结果boolean
     */
    substr: (str: string, start?: number, end?: number | string, right?: string) => string | boolean;
    /**
     * 返回数据类型
     * @param {string} val 要获取数据类型的值
     * @param {number} matching 类型匹配判断
     * @return {string|boolean} 如果不指定right字符，则返回指定位置的字符串，否则将返回对比结果boolean
     */
    typeof: (val: any, matching?: any) => any;
    /**
     * 判断是否为dom数据
     * @param {string} val
     * @return {boolean}
     */
    isDOM: (val: any) => any;
    /**
     * 判断是否为dom数据
     * @param {string} val
     * @return {boolean}
     */
    isEvent: (val: Event) => boolean;
    uuid2: (len: number, radix: number) => string;
    escapeHTMLString: (str?: string) => string;
    escapeStringHTML: (str?: string) => string;
    textToHtml: (text?: string) => string;
    htmlToText: (text?: string) => string;
    upperCase: (str?: string) => string;
    lowerCase: (str?: string) => string;
    firstWordUpperCase: (str?: string) => string;
    firstWordLowerCase: (str?: string) => string;
    lineToHump: (str?: string, line?: string) => string;
    humpToLine: (str?: string, line?: string) => string;
    clone: (obj: any) => any;
    isEmptyElement(c: any): boolean;
    getScopedSlots: (ele: any) => any;
    getSlots: (ele: any) => any;
    /**
     * 递归工具函数，从某一个节点开始递归，同时支持子节点为数组或对象
     * @param {array|object} node 要处理的节点
     * @param {string} childField 子节点属性名
     * @param {object} parent 被处理节点的父节点
     * @param {function} before 前置方法
     * @param {function} after 后置方法
     * @return {array|object}
     */
    recursionNode: (node: any, childField?: string, parent?: any, before?: ((node: any, parent: any) => object) | null, after?: ((node: any, parent: any) => object) | null) => any;
    /**
     * 递归工具函数，从某一个节点开始递归，同时支持子节点为数组或对象
     * @param {array} parent 父节点 或 直接为要循环的数组
     * @param {string} childField 子节点属性名
     * @param {function} callback 循环中的回调方法
     * @param {string|string[]|function} remove 循环节点是否需要删除的方法或配置
     * @return {array}
     */
    recursionArray: (parent: any, childField?: string, callback?: string | string[] | ((node: any, parent?: any) => any) | null, remove?: string | string[] | ((node: any, parent?: any) => boolean)) => any;
    throttle: (fn: {
        apply: (arg0: any, arg1: any[]) => void;
    }, t: number) => (this: any, ...args: any) => void;
    debounce: (fn: {
        apply: (arg0: any, arg1: any) => void;
    }, t: number) => (this: any, ...args: any) => void;
    /**
     * 循环查找父节点的函数
     * @param {object} 开始查找的节点
     * @param {function|boolean} callback 返回父节点 或 Bollean 来确定是否继续循环查找或是否找到或终止
     * @return {array}
     */
    searchParent: (node: any, callback: Function) => null;
    isNum: (str: any, _default?: any) => any;
    toNum: (str: any, _default?: any, afterDot?: boolean) => any;
    toInteger: (str: any) => number;
    getPathCheck: (path: string | string[], separator?: string) => {
        status: boolean;
        data: string;
        msg: string;
    };
    /**
     * 返回object或array指定path的值，并支持赋值
     * @param {object|array} data 数据源
     * @param {string|string[]} path 需要从数据源里获取数据的路径
     * @param {string} separator 路径分隔符
     * @param {any} value 获取不到值返回的默认值
     * @param {boolean} mode 赋值逻辑处理方式
                          0  返回指定path的值，不存在则返回value或undefined
                          1  返回指定path的值，不存在则将value赋值给path后再返回path的值，value为undefined时不发生赋值（取值时默认）
                          2  返回指定path的值，不存在则将value赋值给path后再返回path的值
                          3  返回指定path的值，返回之前会固定将value赋值给path，value为undefined除外（赋值时默认）
                          4  返回指定path的值，返回之前会固定将value赋值给path
     * @param {boolean} modify 如果是赋值操作，且置顶的参数已经定义，是否修改已定义的值，默认true
     * @param {boolean} complement 路径查找中途遇到object或array节点未定义的情况是否自动创建{}或[]
     * @return {object|array}
     */
    pathValue(data?: any, path?: number | string | string[], value?: any, mode?: number, complement?: boolean, separator?: string): {
        status: number;
        value: any;
        key: string;
        parent: any;
        data: any;
        msg: string;
    } | {
        status: boolean;
        value: any;
        key: string;
        parent: any;
        data: any;
        msg: string;
    };
    setPathValue: (data: any, path: string | string[] | undefined, value: any, assignment?: number, separator?: string) => {
        status: number;
        value: any;
        key: string;
        parent: any;
        data: any;
        msg: string;
    } | {
        status: boolean;
        value: any;
        key: string;
        parent: any;
        data: any;
        msg: string;
    };
    getPathValue: (data?: any, path?: string | string[], _default?: any, separator?: string) => {
        status: number;
        value: any;
        key: string;
        parent: any;
        data: any;
        msg: string;
    } | {
        status: boolean;
        value: any;
        key: string;
        parent: any;
        data: any;
        msg: string;
    };
    /**
     * 差集
     * @param {array} arrOld 旧数组
     * @param {array} arrNew 新数组
     * @param {array} onlyNew 是否只取新数组的差集
     * @return {array}
     */
    diffArray: (arrNew?: never[], arrOld?: never[], onlyNew?: boolean) => never[];
    intersectArray: (arr1?: never[], arr2?: never[]) => never[];
    getTypeDefault: (type: string | string[], _default?: any, booleanDefault?: null | boolean) => any;
    flattenArray: (arr: any[]) => any[];
    flattenNodeList: (arr: any[]) => any[];
    getTimestamp: (ms?: boolean) => number;
    random: (chars: string, length?: number) => string;
    getId: (oldIds?: string[], lettersLength?: number, numberLength?: number) => string;
    timestampId: (first?: string, seed?: string) => () => string;
    isVirtualTag: (tag: any, extra?: any) => any;
    each: (data: any, callback: any, loopType?: 'forEach' | 'map' | 'some' | 'every' | 'filter') => any;
    forEach: (data: any, callback: any) => void;
    some: (data: any, callback: any) => any;
    map: (data: any, callback: any) => any;
    every: (data: any, callback: any) => any;
    filter: (data: any, callback: any) => any;
    /**
     * 递归工具函数，从某一个节点开始递归，同时支持子节点为数组或对象
     * @param {array} parent 父节点 或 直接为要循环的数组
     * @param {string} childField 子节点属性名
     * @param {function} callback 循环中的回调方法
     * @param {string|string[]|function} remove 循环节点是否需要删除的方法或配置
     * @return {array}
     */
    recursion: (data: any, parent?: any[] | Record<string, unknown> | Recursion, callback?: Recursion | number | string, layer?: number | string, newType?: string) => any;
    jsonStringify: (data: any, replacer?: any, space?: number | string, success?: (str: any) => any, error?: any) => any;
    jsonParse: (str: any, success?: (obj: any) => any, error?: any, reviver?: any) => any;
    add: (left: number, right: number) => number;
    subtract: (left: number, right: number) => number;
    multiply: (left: number, right: number) => number;
    divide: (left: number, right: number) => number;
    mod: (left: number, right: number) => number;
    eventValue: (value: any) => any;
    dataAdd: (data: any, key: string | number | null, value: any, clone?: boolean) => any;
    insert: (data: any, value: any, path: any[] | string | number) => any;
    dataEdit: (data: any, key: string | number | null, value: any, clone?: boolean) => any;
    dataRemove: (data: any, key: string | string, clone?: boolean) => any;
    clear(data: any): any;
    length: (data: any) => any;
    empty(data: any): boolean;
    exist(data: any): any;
    split: (str: string, separate1: string | number, limit1?: string | number, separate2?: string | number | Function | Boolean, limit2?: number | Function | Boolean, objectCallback?: Function | null | Boolean) => any;
    toStyle: (str: string | {
        [key: string]: string | number;
    }) => {
        [key: string]: string | number;
    };
    toClass: (str: string | string[]) => string[];
};
export default AS;
//# sourceMappingURL=as.d.ts.map